@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: affile.c,v 1.31.2.4 2001/07/11 14:08:16 bazsi Exp $
+ * $Id: affile.c,v 1.31.2.5 2002/04/26 09:44:59 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -539,7 +539,7 @@ affile_find_writer(struct affile_dest *self,
 	if (self->flags & AFFILE_NO_EXPAND) {
 		if (self->writers) 
 			return self->writers;
-		self->writers = make_affile_dest_writer(self, self->template_fname);
+		self->writers = make_affile_dest_writer(self, ol_string_use(self->template_fname));
 		res = LOG_HANDLER_INIT(self->writers, self->cfg, NULL);
 		if (res & ST_QUIT)
 			return NULL;
